#!/bin/csh
echo "#################################################################################"
echo 128x2 linear least squares examples

echo binary input and 2 processes in one column
mpirun -np 2 ../bin/acre -acre_fA data/lsqr_A		\
	-acre_fb data/lsqr_b				\
	-acre_fsL data/lsqr_sL				\
	-acre_flb data/lsqr_lb				\
	-acre_fub data/lsqr_ub				\
	-acre_fx data/lsqr_x				\
	-acre_exact 1.0e-15				\
	-acre_silent >&! outputs/lsqr_1.out

echo ASCII input and 2 processes in one column 
mpirun -np 2 ../bin/acre -acre_fA data/lsqr_A_txt	\
	-acre_fb data/lsqr_b_txt			\
	-acre_fsL data/lsqr_sL_txt			\
	-acre_flb data/lsqr_lb_txt			\
	acre_fub data/lsqr_ub_txt			\
	-acre_fx data/lsqr_x_txt			\
	-acre_ascii					\
	-acre_exact 1.0e-15				\
	-acre_silent >&! outputs/lsqr_2.out

echo binary input and 2 processs in one row
mpirun -np 2 ../bin/acre -acre_fA data/lsqr_A		\
	-acre_fb data/lsqr_b				\
	-acre_g cramer					\
	-acre_fsL data/lsqr_sL				\
	-acre_flb data/lsqr_lb				\
	-acre_fub data/lsqr_ub				\
	-acre_fx data/lsqr_x				\
	-acre_xc 2					\
	-acre_exact 1.0e-15				\
	-acre_silent >&! outputs/lsqr_3.out

echo ASCII input and 2 processes in one row
mpirun -np 2 ../bin/acre -acre_fA data/lsqr_A_txt	\
	-acre_fb data/lsqr_b_txt			\
	-acre_fsL data/lsqr_sL_txt			\
	-acre_flb data/lsqr_lb_txt			\
	-acre_fub data/lsqr_ub_txt			\
	-acre_fx data/lsqr_x_txt			\
	-acre_ascii					\
	-acre_xc 2					\
	-acre_exact 1.0e-15				\
	-acre_silent >&! outputs/lsqr_4.out

echo binary input, 2 processes in one column, adjoint formulation
mpirun -np 2 ../bin/acre -acre_fA data/lsqr_A		\
	-acre_fb data/lsqr_b				\
	-acre_fsL data/lsqr_sL				\
	-acre_flb data/lsqr_lb				\
	-acre_fub data/lsqr_ub				\
	-acre_fx data/lsqr_x				\
	-acre_g adjoint					\
	-acre_exact 1.0e-15				\
	-acre_silent >&! outputs/lsqr_5.out

echo binary input, 2 processes in one column, ML estimates and Cramer formulation
mpirun -np 2 ../bin/acre -acre_fA data/lsqr_A		\
	-acre_fb data/lsqr_b				\
	-acre_fsL data/lsqr_sL				\
	-acre_flb data/lsqr_lb				\
	-acre_fub data/lsqr_ub				\
	-acre_fx data/lsqr_x				\
	-acre_g cramer					\
	-acre_ml					\
	-acre_exact 1.0e-15				\
	-acre_silent >&! outputs/lsqr_6.out

echo binary input, 2 processes in one row, ML estimates and Cramer formulation
mpirun -np 2 ../bin/acre -acre_fA data/lsqr_A		\
	-acre_fb data/lsqr_b				\
	-acre_fsL data/lsqr_sL				\
	-acre_flb data/lsqr_lb				\
	-acre_fub data/lsqr_ub				\
	-acre_fx data/lsqr_x				\
	-acre_xc 2					\
	-acre_g cramer					\
	-acre_ml					\
	-acre_exact 1.0e-15				\
	-acre_silent >&! outputs/lsqr_7.out

echo binary input, 2 processes in one row, ML estimates and Cramer formulation
mpirun -np 2 ../bin/acre -acre_fA data/lsqr_A		\
	-acre_fb data/lsqr_b				\
	-acre_fsL data/lsqr_sL				\
	-acre_flb data/lsqr_lb				\
	-acre_fub data/lsqr_ub				\
	-acre_fx data/lsqr_x				\
	-acre_xc 2					\
	-acre_g cramer					\
	-acre_ml					\
	-acre_exact 1.0e-15				\
	-acre_silent >&! outputs/lsqr_8.out

echo binary input, 2 processes in one column, ML estimates and adjoint formulation
mpirun -np 2 ../bin/acre -acre_fA data/lsqr_A		\
	-acre_fb data/lsqr_b				\
	-acre_fsL data/lsqr_sL				\
	-acre_flb data/lsqr_lb				\
	-acre_fub data/lsqr_ub				\
	-acre_fx data/lsqr_x				\
	-acre_g adjoint					\
	-acre_ml					\
	-acre_exact 1.0e-15				\
	-acre_silent >&! outputs/lsqr_9.out

echo "#################################################################################"
echo 128x2 2-band examples

echo binary input and 2 processes in one column
mpirun -np 2 ../bin/acre -acre_fA data/band_A		\
	-acre_fb data/band_b				\
	-acre_fsL data/band_sL				\
	-acre_flb data/band_lb				\
	-acre_fub data/band_ub				\
	-acre_fx data/band_x				\
	-acre_exact 1.0e-7				\
	-acre_silent >&! outputs/band_1.out

echo ASCII input and 2 processes in one column 
mpirun -np 2 ../bin/acre -acre_fA data/band_A_txt	\
	-acre_fb data/band_b_txt			\
	-acre_fsL data/band_sL_txt			\
	-acre_flb data/band_lb_txt			\
	-acre_fub data/band_ub_txt			\
	-acre_fx data/band_x_txt			\
	-acre_ascii					\
	-acre_exact 1.0e-7				\
	-acre_silent >&! outputs/band_2.out

echo binary input and 2 processs in one row
mpirun -np 2 ../bin/acre -acre_fA data/band_A		\
	-acre_fb data/band_b				\
	-acre_g cramer					\
	-acre_fsL data/band_sL				\
	-acre_flb data/band_lb				\
	-acre_fub data/band_ub				\
	-acre_fx data/band_x				\
	-acre_xc 2					\
	-acre_exact 1.0e-7				\
	-acre_silent >&! outputs/band_3.out

echo ASCII input and 2 processes in one row
mpirun -np 2 ../bin/acre -acre_fA data/band_A_txt	\
	-acre_fb data/band_b_txt			\
	-acre_fsL data/band_sL_txt			\
	-acre_flb data/band_lb_txt			\
	-acre_fub data/band_ub_txt			\
	-acre_fx data/band_x_txt			\
	-acre_ascii					\
	-acre_xc 2					\
	-acre_exact 1.0e-7				\
	-acre_silent >&! outputs/band_4.out

echo binary input, 2 processes in one column, adjoint formulation
mpirun -np 2 ../bin/acre -acre_fA data/band_A		\
	-acre_fb data/band_b				\
	-acre_fsL data/band_sL				\
	-acre_flb data/band_lb				\
	-acre_fub data/band_ub				\
	-acre_fx data/band_x				\
	-acre_g adjoint					\
	-acre_exact 1.0e-7				\
	-acre_silent >&! outputs/band_5.out

echo binary input, 2 processes in one column, ML estimates and Cramer formulation
mpirun -np 2 ../bin/acre -acre_fA data/band_A		\
	-acre_fb data/band_b				\
	-acre_fsL data/band_sL				\
	-acre_flb data/band_lb				\
	-acre_fub data/band_ub				\
	-acre_fx data/band_x				\
	-acre_g cramer					\
	-acre_ml					\
	-acre_exact 1.0e-7				\
	-acre_silent >&! outputs/band_6.out

echo binary input, 2 processes in one row, ML estimates and Cramer formulation
mpirun -np 2 ../bin/acre -acre_fA data/band_A		\
	-acre_fb data/band_b				\
	-acre_fsL data/band_sL				\
	-acre_flb data/band_lb				\
	-acre_fub data/band_ub				\
	-acre_fx data/band_x				\
	-acre_xc 2					\
	-acre_g cramer					\
	-acre_ml					\
	-acre_exact 1.0e-7				\
	-acre_silent >&! outputs/band_7.out

echo binary input, 2 processes in one row, ML estimates and Cramer formulation
mpirun -np 2 ../bin/acre -acre_fA data/band_A		\
	-acre_fb data/band_b				\
	-acre_fsL data/band_sL				\
	-acre_flb data/band_lb				\
	-acre_fub data/band_ub				\
	-acre_fx data/band_x				\
	-acre_xc 2					\
	-acre_g cramer					\
	-acre_ml					\
	-acre_exact 1.0e-7				\
	-acre_silent >&! outputs/band_8.out

echo binary input, 2 processes in one column, ML estimates and adjoint formulation
mpirun -np 2 ../bin/acre -acre_fA data/band_A		\
	-acre_fb data/band_b				\
	-acre_fsL data/band_sL				\
	-acre_flb data/band_lb				\
	-acre_fub data/band_ub				\
	-acre_fx data/band_x				\
	-acre_g adjoint					\
	-acre_ml					\
	-acre_exact 1.0e-7				\
	-acre_silent >&! outputs/band_9.out

echo "#################################################################################"
echo 128x2 2x2-blocks examples

echo binary input and 2 processes in one column
mpirun -np 2 ../bin/acre -acre_fA data/block_A		\
	-acre_fb data/block_b				\
	-acre_fsL data/block_sL				\
	-acre_flb data/block_lb				\
	-acre_fub data/block_ub				\
	-acre_fx data/block_x				\
	-acre_exact 1.0e-9				\
	-acre_silent >&! outputs/block_1.out

echo ASCII input and 2 processes in one column 
mpirun -np 2 ../bin/acre -acre_fA data/block_A_txt	\
	-acre_fb data/block_b_txt			\
	-acre_fsL data/block_sL_txt			\
	-acre_flb data/block_lb_txt			\
	-acre_fub data/block_ub_txt			\
	-acre_fx data/block_x_txt			\
	-acre_ascii					\
	-acre_exact 1.0e-9				\
	-acre_silent >&! outputs/block_2.out

echo binary input and 2 processs in one row
mpirun -np 2 ../bin/acre -acre_fA data/block_A		\
	-acre_fb data/block_b				\
	-acre_g cramer					\
	-acre_fsL data/block_sL				\
	-acre_flb data/block_lb				\
	-acre_fub data/block_ub				\
	-acre_fx data/block_x				\
	-acre_xc 2					\
	-acre_exact 1.0e-9				\
	-acre_silent >&! outputs/block_3.out

echo ASCII input and 2 processes in one row
mpirun -np 2 ../bin/acre -acre_fA data/block_A_txt	\
	-acre_fb data/block_b_txt			\
	-acre_fsL data/block_sL_txt			\
	-acre_flb data/block_lb_txt			\
	-acre_fub data/block_ub_txt			\
	-acre_fx data/block_x_txt			\
	-acre_ascii					\
	-acre_xc 2					\
	-acre_exact 1.0e-9				\
	-acre_silent >&! outputs/block_4.out

echo binary input, 2 processes in one column, adjoint formulation
mpirun -np 2 ../bin/acre -acre_fA data/block_A		\
	-acre_fb data/block_b				\
	-acre_fsL data/block_sL				\
	-acre_flb data/block_lb				\
	-acre_fub data/block_ub				\
	-acre_fx data/block_x				\
	-acre_g adjoint					\
	-acre_exact 1.0e-9				\
	-acre_silent >&! outputs/block_5.out

echo binary input, 2 processes in one column, ML estimates and Cramer formulation
mpirun -np 2 ../bin/acre -acre_fA data/block_A		\
	-acre_fb data/block_b				\
	-acre_fsL data/block_sL				\
	-acre_flb data/block_lb				\
	-acre_fub data/block_ub				\
	-acre_fx data/block_x				\
	-acre_g cramer					\
	-acre_ml					\
	-acre_exact 1.0e-9				\
	-acre_silent >&! outputs/block_6.out

echo binary input, 2 processes in one row, ML estimates and Cramer formulation
mpirun -np 2 ../bin/acre -acre_fA data/block_A		\
	-acre_fb data/block_b				\
	-acre_fsL data/block_sL				\
	-acre_flb data/block_lb				\
	-acre_fub data/block_ub				\
	-acre_fx data/block_x				\
	-acre_xc 2					\
	-acre_g cramer					\
	-acre_ml					\
	-acre_exact 1.0e-9				\
	-acre_silent >&! outputs/block_7.out

echo binary input, 2 processes in one row, ML estimates and Cramer formulation
mpirun -np 2 ../bin/acre -acre_fA data/block_A		\
	-acre_fb data/block_b				\
	-acre_fsL data/block_sL				\
	-acre_flb data/block_lb				\
	-acre_fub data/block_ub				\
	-acre_fx data/block_x				\
	-acre_xc 2					\
	-acre_g cramer					\
	-acre_ml					\
	-acre_exact 1.0e-9				\
	-acre_silent >&! outputs/block_8.out

echo binary input, 2 processes in one column, ML estimates and adjoint formulation
mpirun -np 2 ../bin/acre -acre_fA data/block_A		\
	-acre_fb data/block_b				\
	-acre_fsL data/block_sL				\
	-acre_flb data/block_lb				\
	-acre_fub data/block_ub				\
	-acre_fx data/block_x				\
	-acre_g adjoint					\
	-acre_ml					\
	-acre_exact 1.0e-9				\
	-acre_silent >&! outputs/block_9.out

echo "#################################################################################"
echo All tests ran, please check the .out files in directory outputs.
