/*$Id: acre_fd_backward.c,v 1.1 2004/04/30 J. Malard Exp d3j540 $ */

#include "tao_solver.h"
#include "petscblaslapack.h"
#include "acre.h"
#include "copyright.h"
#undef __FUNC__
#define __FUNC__ "acre_fd_backward"
int acre_fd_backward(acre_cntxt *cntxt, Mat F)
{
	int n;
	int i, j, k, ierr;
	int nrows, start, end, *rows;
	Vec qk;
	Vec qj;
	Vec fk;
	Vec fj;
	PetscScalar u, w; 
	PetscScalar *ub, *vals;

	HELLO("acre_fd_backward enter");
	n = cntxt->n;

	ierr = PetscMalloc(n*sizeof(PetscScalar),&ub);		CHKERRQ(ierr);
	ierr = VecDuplicate (cntxt->b, &qk);			CHKERRQ(ierr); 
	ierr = VecDuplicate (cntxt->b, &qj);			CHKERRQ(ierr); 
	ierr = VecDuplicate (cntxt->b, &fk);			CHKERRQ(ierr); 
	ierr = VecDuplicate (cntxt->b, &fj);			CHKERRQ(ierr);
	ierr = VecGetOwnershipRange (qk, &start, &end);		CHKERRQ(ierr);
	nrows = end-start;
	rows = NULL;
	if ( nrows!=0 )
	{
		ierr = PetscMalloc(nrows*sizeof(int),&rows);	CHKERRQ(ierr);
		for ( i=0; i<nrows; i++ ) rows[i] = i+start;
	}

	/* Set the initial adjoints */
	ierr = MatZeroEntries( F );				CHKERRQ(ierr);
	ierr = MatAssemblyBegin( F, MAT_FINAL_ASSEMBLY );	CHKERRQ(ierr);
	ierr = MatAssemblyEnd( F , MAT_FINAL_ASSEMBLY );	CHKERRQ(ierr);
	for ( i=0; i<n; i++ )
	{
		ierr = MatGetValues(cntxt->R,1,&i,1,&i,&w);	CHKERRQ(ierr);
		ub[i] = 1.0/(w*w);
	}

	/* The backward phase */
	for ( k=n-1; k>=0; k-- )
	{
		ierr = acre_get_dense_matrix_column_vector(
			cntxt->Q, qk, k);			CHKERRQ(ierr);
		ierr = acre_get_dense_matrix_column_vector(
			F, fk, k);				CHKERRQ(ierr);
		ierr = MatGetValues(cntxt->R, 1, &k, 1, &k,
			&w);					CHKERRQ(ierr);
		ierr = VecScale ( &w, qk );			CHKERRQ(ierr); 
		ierr = VecDot ( qk, fk, &u );			CHKERRQ(ierr);
		w = 1.0/w;
		u *= -0.5*w*w*w;
		ub[k] += u;
		u = 2*ub[k];
		ierr = VecAXPBY( &u, &w, qk, fk);		CHKERRQ(ierr);

		for ( j=k-1; j>=0; j-- )
		{
			ierr = acre_get_dense_matrix_column_vector(
				cntxt->Q, qj, j );		CHKERRQ(ierr);
			ierr = acre_get_dense_matrix_column_vector(
				F, fj, j );			CHKERRQ(ierr);
			ierr = MatGetValues(cntxt->R, 1, &j,
				1, &k, &u);			CHKERRQ(ierr);
			ierr = VecAXPY (&u, qj, qk );		CHKERRQ(ierr);
			ierr = VecDot ( qj, fk, &w );		CHKERRQ(ierr);
			w = -w;
			u = -u;
			ierr = VecAXPY (&u, fk, fj );		CHKERRQ(ierr); 
			ierr = VecAXPY (&w, qk, fj );		CHKERRQ(ierr);
			ierr = VecAXPY (&w, qk, fk );		CHKERRQ(ierr); 

			ierr = VecGetArray ( fj, &vals );	CHKERRQ(ierr);
			ierr = MatSetValues ( F, nrows, rows,
				1, &j, vals, INSERT_VALUES);	CHKERRQ(ierr); 
			ierr = VecRestoreArray ( fj, &vals );	CHKERRQ(ierr);

			ierr = MatAssemblyBegin(F,
				MAT_FINAL_ASSEMBLY);		CHKERRQ(ierr);
			ierr = MatAssemblyEnd(F,
				MAT_FINAL_ASSEMBLY);		CHKERRQ(ierr);
		}

		ierr = VecGetArray ( fk, &vals );		CHKERRQ(ierr);
		ierr = MatSetValues ( F, nrows, rows, 1, &k, 
			vals, INSERT_VALUES);			CHKERRQ(ierr); 
		ierr = VecRestoreArray ( fk, &vals );		CHKERRQ(ierr);

		ierr = MatAssemblyBegin( F,
			MAT_FINAL_ASSEMBLY );			CHKERRQ(ierr);
		ierr = MatAssemblyEnd( F,
			MAT_FINAL_ASSEMBLY );			CHKERRQ(ierr);
	}

	PetscFree(ub);
	ierr = VecDestroy ( qk );				CHKERRQ(ierr); 
	ierr = VecDestroy ( qj );				CHKERRQ(ierr); 
	ierr = VecDestroy ( fk );				CHKERRQ(ierr);
	ierr = VecDestroy ( fj );				CHKERRQ(ierr);

	if ( nrows!=0 ) PetscFree (rows);

	HELLO("acre_fd_backward exit");

	return 0;

}
